==> lokum-0.2.1.tgz: package/lib/startServerForBoard.js <==
'use strict';

var Hapi = require('hapi');
var Axios = require('axios');
var R = require('ramda');
var speakeasy = require('speakeasy');

var _require = require('./trello'),
    routesForTrelloData = _require.routesForTrelloData,
    promiseEnhancedTrelloCards = _require.promiseEnhancedTrelloCards;

function startServerForBoard(boardID) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        _ref$seo = _ref.seo,
        seo = _ref$seo === undefined ? true : _ref$seo,
        reloadSecret = _ref.reloadSecret,
        host = _ref.host,
        port = _ref.port;

    var server = new Hapi.Server();
    server.connection({
        address: host,
        port: port
    });

    server.route({
        method: 'GET',
        path: '/-raw',
        handler: function handler(request, reply) {
            reply(JSON.stringify(boardJSON, null, 2));
        }
    });

    if (seo) {
        server.route({
            method: 'GET',
            path: '/robots.txt',
            handler: function handler(request, reply) {
                reply('User-agent: *\nDisallow:\n'

                // Sitemap: https://burntcaramel.github.io/sitemap.xml
                ).type('text/plain');
            }
        });

        // TODO: sitemap
    }

    var reloadableServer = void 0;

    function reloadFromTrello() {
        return Axios.get('https://trello.com/b/' + boardID + '.json').then(function (_ref2) {
            var boardJSON = _ref2.data;

            console.log('Loaded content from Trello', boardID);

            return promiseEnhancedTrelloCards(boardJSON.cards).then(function (cards) {
                console.log('Enhanced cards');

                var enhancedBoardJSON = R.merge(boardJSON, { cards: cards });

                reloadableServer = new Hapi.Server();
                var reloadableConnection = reloadableServer.connection({ autoListen: false });
                reloadableServer.route(routesForTrelloData(enhancedBoardJSON));

                // Used for testing
                return { boardJSON: boardJSON, enhancedBoardJSON: enhancedBoardJSON };
            });
        });
    }

    if (reloadSecret) {
        server.route({
            method: 'GET',
            path: '/-reload/{token}',
            handler: function handler(request, reply) {
                var token = request.params.token;

                var verified = speakeasy.totp.verify({
                    secret: reloadSecret,
                    encoding: 'base32',
                    token: token
                });

                if (verified) {
                    reloadFromTrello().then(function () {
                        return reply({ success: true });
                    }).catch(reply);
                } else {
                    reply(new Error('Invalid token'));
                }
            }
        });
    }

    server.route({
        method: '*',
        path: '/{p*}',
        handler: function handler(request, reply) {
            if (!reloadableServer) {
                reply(new Error('Content has not loaded from Trello'));
                return;
            }

            console.log(request.url, request.params);
            reloadableServer.inject(request.url.href).then(function (innerResponse) {
                console.log(innerResponse);
                var outerResponse = reply(innerResponse.rawPayload);
                outerResponse.code(innerResponse.statusCode);
                Object.keys(innerResponse.headers).map(function (key) {
                    outerResponse.header(key, innerResponse.headers[key]);
                });
            });
        }
    });

    server.start();

    return reloadFromTrello().then(function (_ref3) {
        var boardJSON = _ref3.boardJSON,
            enhancedBoardJSON = _ref3.enhancedBoardJSON;

        console.log('Started server');
        return {
            // Used for testing
            internal: {
                boardJSON: boardJSON,
                enhancedBoardJSON: enhancedBoardJSON,
                server: server,
                reloadableServer: reloadableServer
            }
        };
    });
}

module.exports = startServerForBoard;

==> lokum-0.2.2.tgz: package/lib/startServerForBoard.js <==
'use strict';

var Hapi = require('hapi');
var Axios = require('axios');
var R = require('ramda');
var speakeasy = require('speakeasy');

var _require = require('./trello'),
    routesForTrelloData = _require.routesForTrelloData,
    promiseEnhancedTrelloCards = _require.promiseEnhancedTrelloCards;

function startServerForBoard(boardID) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        _ref$seo = _ref.seo,
        seo = _ref$seo === undefined ? true : _ref$seo,
        reloadSecret = _ref.reloadSecret,
        host = _ref.host,
        port = _ref.port;

    var server = new Hapi.Server();
    server.connection({
        address: host,
        port: port
    });

    server.route({
        method: 'GET',
        path: '/-raw',
        handler: function handler(request, reply) {
            reply(JSON.stringify(boardJSON, null, 2));
        }
    });

    if (seo) {
        server.route({
            method: 'GET',
            path: '/robots.txt',
            handler: function handler(request, reply) {
                reply('User-agent: *\nDisallow:\n'

                // Sitemap: https://burntcaramel.github.io/sitemap.xml
                ).type('text/plain');
            }
        });

        // TODO: sitemap
    }

    var reloadableServer = void 0;

    function reloadFromTrello() {
        return Axios.get('https://trello.com/b/' + boardID + '.json').then(function (_ref2) {
            var boardJSON = _ref2.data;

            console.log('Loaded content from Trello', boardID);

            return promiseEnhancedTrelloCards(boardJSON.cards).then(function (cards) {
                console.log('Enhanced cards');

                var enhancedBoardJSON = R.merge(boardJSON, { cards: cards });

                reloadableServer = new Hapi.Server();
                var reloadableConnection = reloadableServer.connection({ autoListen: false });
                reloadableServer.route(routesForTrelloData(enhancedBoardJSON));

                // Used for testing
                return { boardJSON: boardJSON, enhancedBoardJSON: enhancedBoardJSON };
            });
        });
    }

    if (reloadSecret) {
        server.route({
            method: 'GET',
            path: '/-reload/{token}',
            handler: function handler(request, reply) {
                var token = request.params.token;

                var verified = speakeasy.totp.verify({
                    secret: reloadSecret,
                    encoding: 'base32',
                    token: token
                });

                if (verified) {
                    reloadFromTrello().then(function () {
                        return reply({ success: true });
                    }).catch(reply);
                } else {
                    reply(new Error('Invalid token'));
                }
            }
        });
    }

    server.route({
        method: '*',
        path: '/{p*}',
        handler: function handler(request, reply) {
            if (!reloadableServer) {
                reply(new Error('Content has not loaded from Trello'));
                return;
            }

            //console.log(request.url, request.params)
            reloadableServer.inject(request.url.href).then(function (innerResponse) {
                //console.log(innerResponse)
                var outerResponse = reply(innerResponse.rawPayload);
                outerResponse.code(innerResponse.statusCode);
                Object.keys(innerResponse.headers).map(function (key) {
                    outerResponse.header(key, innerResponse.headers[key]);
                });
            });
        }
    });

    server.start();

    return reloadFromTrello().then(function (_ref3) {
        var boardJSON = _ref3.boardJSON,
            enhancedBoardJSON = _ref3.enhancedBoardJSON;

        console.log('Started server on port', server.info.port);
        return {
            // Used for testing
            internal: {
                boardJSON: boardJSON,
                enhancedBoardJSON: enhancedBoardJSON,
                server: server,
                reloadableServer: reloadableServer
            }
        };
    });
}

module.exports = startServerForBoard;
